/*
 * support2.c
 */

#include <stdio.h>
#include <stdlib.h>

#include "support2.h"


char *newExtension(const char *aPathname, const char *aExtension)
{
	const char	*s;
	const char	*e;
	char		*outFilename;
	char		*d;
	char		c;
	unsigned short	l;

	outFilename = NULL;
	s = aPathname;
	e = NULL;
	c = *s++;
	while(c)
	{
		if('.' == c)
		{
			e = s;
		}
		else if('/' == c || '\\' == c || ':' == c)
		{
			e = NULL;
		}
		c = *s++;
	}
	s--;
	if(e)
	{
		s = e - 1;	/* extension dot */
	}

	l = s - aPathname;

	s = aExtension;
	c = *s++;
	while(c)
	{
		c = *s++;
	}

	outFilename = (char *) malloc(l + 1 + (s - aExtension));
	if(outFilename)
	{
		d = outFilename;
		s = aPathname;
		while(l--)
		{
			*d++ = *s++;
		}
		s = aExtension;
		if(s && s[0])
		{
			c = *s++;
			if(c != '.')
			{
				*d++ = '.';
			}
			while(c)
			{
				*d++ = c;
				c = *s++;
			}
		}
		*d = '\0';
	}
	return(outFilename);
}

const char *getGALName(uint8_t aGalType)
{
	static const char	*gal16V8 = "GAL16V8";
	static const char	*gal20V8 = "GAL20V8";
	static const char	*gal22V10 = "GAL22V10";
	static const char	*gal20RA10 = "GAL20RA10";

	switch(aGalType)
	{
	  case GAL16V8:
		return(gal16V8);
	  case GAL20V8:
		return(gal20V8);
	  case GAL22V10:
		return(gal22V10);
	  case GAL20RA10:
		return(gal20RA10);
	}
	return(NULL);
}

const uint8_t *fload(const char *aPathname)
{
	FILE		*fp;
	uint32_t	length;
	uint32_t	len;
	uint8_t	*buffer;

	buffer = NULL;
	fp = fopen(aPathname, "r");
	if(fp)
	{
		fseek(fp, 0, SEEK_END);
		length = ftell(fp);
		fseek(fp, 0, SEEK_START);

		buffer = malloc(sizeof(uint8_t) * length + 1);

		len = fread(buffer, sizeof(buffer[0]), length, fp);
		if(len == length)
		{
			buffer[length] = 0;
		}
		else
		{
			free(buffer);
			buffer = NULL;
		}
		fclose(fp);
	}
	return(buffer);
}

uint8_t fsave(const char *aPathname, const void *aBuffer, uint32_t aLength)
{
	FILE		*fp;
	uint32_t	len;

	fp = fopen(aPathname, "w");
	if(fp)
	{
		len = fwrite(buffer, sizeof(buffer[0]), aLength, fp);
		fclose(fp);
		if(len == aLength)
		{
			return(0);
		}
	}
	return(FILE_WRITE_ERROR);
}


